Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(773)

Unified Diff: src/shared/ppapi_proxy/command_buffer_nacl.h

Issue 7631010: NaCl Proxy for graphics3d. (Closed) Base URL: svn://svn.chromium.org/native_client/trunk/src/native_client/
Patch Set: '' Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/shared/ppapi_proxy/build.scons ('k') | src/shared/ppapi_proxy/command_buffer_nacl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/shared/ppapi_proxy/command_buffer_nacl.h
===================================================================
--- src/shared/ppapi_proxy/command_buffer_nacl.h (revision 6482)
+++ src/shared/ppapi_proxy/command_buffer_nacl.h (working copy)
@@ -6,7 +6,8 @@
#define NATIVE_CLIENT_SRC_SHARED_PPAPI_PROXY_COMMAND_BUFFER_NACL_H
#include "gpu/command_buffer/common/command_buffer.h"
-#include "native_client/src/third_party/ppapi/c/dev/ppb_context_3d_trusted_dev.h"
+#include "native_client/src/third_party/ppapi/c/dev/pp_graphics_3d_dev.h"
+#include "native_client/src/third_party/ppapi/c/dev/ppb_graphics_3d_trusted_dev.h"
#include "native_client/src/third_party/ppapi/c/pp_resource.h"
struct PPB_Core;
@@ -16,8 +17,8 @@
class CommandBufferNacl : public gpu::CommandBuffer {
public:
- // This class will addref the context 3d resource using the core interface.
- CommandBufferNacl(PP_Resource context_3d, const PPB_Core* iface_core);
+ // This class will addref the graphics 3d resource using the core interface.
+ CommandBufferNacl(PP_Resource graphics_3d, const PPB_Core* iface_core);
virtual ~CommandBufferNacl();
// CommandBuffer implementation.
@@ -46,12 +47,12 @@
virtual void SetContextLostReason(gpu::error::ContextLostReason);
private:
- PP_Resource context_3d_;
+ PP_Resource graphics_3d_;
const PPB_Core* iface_core_;
gpu::Buffer buffer_;
State last_state_;
- static gpu::CommandBuffer::State PpapiToGpuState(PP_Context3DTrustedState s);
+ static gpu::CommandBuffer::State PpapiToGpuState(PP_Graphics3DTrustedState s);
static gpu::CommandBuffer::State ErrorGpuState();
static gpu::Buffer BufferFromShm(int shm_handle, uint32_t shm_size);
};
« no previous file with comments | « src/shared/ppapi_proxy/build.scons ('k') | src/shared/ppapi_proxy/command_buffer_nacl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698